==> net.bluemind.p2.platform-5.4.2696.zip: BM/AuthenticationClient.php <==
<?php

/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2017
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
namespace BM;
require_once 'GlobalEnv.php';

/**
 * Implementation of net.bluemind.authentication.api.IAuthentication.
 */

class AuthenticationClient {

  protected $base;
  protected $sid;

  /*
   * Constructor.
   *
   * @param base
   * @param sid
   *
   */
  public function __construct($base, $sid ) {
    $this->sid = $sid;
    $this->base = $base."/api/auth";
  }


  /*
   * @return
   */
  public function getCurrentUser() {
    $postUri = "";
    $method = "GET";


    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param login
   * @param password
   * @param origin
   * @return
   */
  public function login( $login ,  $password ,  $origin  ) {
    $postUri = "/login";
    $method = "POST";


    $url = $this->base.$postUri;

    $queryParam = array(
      "login" => $login,      "origin" => $origin);

    $body = null;
    $body = $password;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param login
   * @param password
   * @param origin
   * @param interactive
   * @return
   */
  public function loginWithParams( $login ,  $password ,  $origin ,  $interactive  ) {
    $postUri = "/loginWithParams";
    $method = "POST";


    $url = $this->base.$postUri;

    $queryParam = array(
      "login" => $login,      "origin" => $origin,      "interactive" => $interactive);

    $body = null;
    $body = $password;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @return
   */
  public function logout() {
    $postUri = "/logout";
    $method = "POST";


    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @return
   */
  public function ping() {
    $postUri = "/ping";
    $method = "GET";


    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param login
   * @return
   */
  public function su( $login  ) {
    $postUri = "/_su";
    $method = "POST";


    $url = $this->base.$postUri;

    $queryParam = array(
      "login" => $login);

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param login
   * @param interactive
   * @return
   */
  public function suWithParams( $login ,  $interactive  ) {
    $postUri = "/_suWithParams";
    $method = "POST";


    $url = $this->base.$postUri;

    $queryParam = array(
      "login" => $login,      "interactive" => $interactive);

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param login
   * @param password
   * @param origin
   * @return
   */
  public function validate( $login ,  $password ,  $origin  ) {
    $postUri = "/validate";
    $method = "POST";


    $url = $this->base.$postUri;

    $queryParam = array(
      "login" => $login,      "origin" => $origin);

    $body = null;
    $body = $password;
    return $this->execute($url, $queryParam, $body, $method);
  }


  /*
   * Execute the request
   *
   * @param url
   * @param data
   * @param body
   */
  private function execute($url, $queryParam, $body, $method) {

    $curl = curl_init();

    $headers = array();
    array_push($headers, 'X-BM-ApiKey: '.$this->sid);

    if (sizeof($queryParam) > 0) {
      $url .= '?'.http_build_query($queryParam);
    }

    curl_setopt_array($curl, GlobalEnv::$curlOptions + array(
      CURLOPT_URL => $url,
      CURLOPT_HTTPHEADER => $headers,
      CURLOPT_CUSTOMREQUEST => $method)
    );

    if ($method == 'POST') {
      curl_setopt($curl, CURLOPT_POST, TRUE);
      curl_setopt($curl, CURLOPT_POSTFIELDS, array());
    }

    if (is_resource($body)) {
      if ($method == 'PUT') {
        curl_setopt($curl, CURLOPT_PUT, TRUE);
      }
      $size = fstat($body)['size'];
      curl_setopt($curl, CURLOPT_INFILE, $body);
      curl_setopt($curl, CURLOPT_INFILESIZE, $size);
    } else {
      if (is_object($body) && method_exists($body, 'serialize')) {
        $body = $body->serialize();
      } else if (is_object($body)) {
        $body = json_encode($body);
      } else if (is_array($body)) {
        $body = json_encode($body);
      } else if (is_string($body)) {
        $body = json_encode($body);
      }
      $size = strlen($body);
      array_push($headers, 'Content-Type: application/json');
      array_push($headers, 'Content-Length: '.$size);
      curl_setopt($curl, CURLOPT_HTTPHEADER, $headers);
      curl_setopt($curl, CURLOPT_POSTFIELDS, $body);
    }

    $resp = curl_exec($curl);
    if ($resp === false) {
      throw new \Exception(curl_error($curl));
    } 
    curl_close($curl);
    if (!$resp) {
      return;
    }
    $js = json_decode($resp);
    if ($js === NULL) {
      return $resp;
    }
    if (isset($js->errorCode)) {
      throw new \Exception($js->errorCode . ': ' . (isset($js->message) ? ' : ' . $js->message : ''));
    }
    return $js;
  }

}

==> net.bluemind.p2.platform-5.5.3112.zip: BM/AuthenticationClient.php <==
<?php

/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2017
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
namespace BM;
require_once 'GlobalEnv.php';

/**
 * Implementation of net.bluemind.authentication.api.IAuthentication.
 */

class AuthenticationClient {

  protected $base;
  protected $sid;

  /*
   * Constructor.
   *
   * @param base
   * @param sid
   *
   */
  public function __construct($base, $sid ) {
    $this->sid = $sid;
    $this->base = $base."/api/auth";
  }


  /*
   * @param contentStream
   * @return
   */
  public function backchannelLogout( $contentStream  ) {
    $postUri = "/logout/backchannel";
    $method = "POST";


    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    $body = $contentStream;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @return
   */
  public function getCurrentUser() {
    $postUri = "";
    $method = "GET";


    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param login
   * @param password
   * @param origin
   * @return
   */
  public function login( $login ,  $password ,  $origin  ) {
    $postUri = "/login";
    $method = "POST";


    $url = $this->base.$postUri;

    $queryParam = array(
      "login" => $login,      "origin" => $origin);

    $body = null;
    $body = $password;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param login
   * @param password
   * @param origin
   * @param interactive
   * @return
   */
  public function loginWithParams( $login ,  $password ,  $origin ,  $interactive  ) {
    $postUri = "/loginWithParams";
    $method = "POST";


    $url = $this->base.$postUri;

    $queryParam = array(
      "login" => $login,      "origin" => $origin,      "interactive" => $interactive);

    $body = null;
    $body = $password;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @return
   */
  public function logout() {
    $postUri = "/logout";
    $method = "POST";


    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @return
   */
  public function ping() {
    $postUri = "/ping";
    $method = "GET";


    $url = $this->base.$postUri;

    $queryParam = array();

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param login
   * @return
   */
  public function su( $login  ) {
    $postUri = "/_su";
    $method = "POST";


    $url = $this->base.$postUri;

    $queryParam = array(
      "login" => $login);

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param login
   * @param interactive
   * @return
   */
  public function suWithParams( $login ,  $interactive  ) {
    $postUri = "/_suWithParams";
    $method = "POST";


    $url = $this->base.$postUri;

    $queryParam = array(
      "login" => $login,      "interactive" => $interactive);

    $body = null;
    return $this->execute($url, $queryParam, $body, $method);
  }

  /*
   * @param login
   * @param password
   * @param origin
   * @return
   */
  public function validate( $login ,  $password ,  $origin  ) {
    $postUri = "/validate";
    $method = "POST";


    $url = $this->base.$postUri;

    $queryParam = array(
      "login" => $login,      "origin" => $origin);

    $body = null;
    $body = $password;
    return $this->execute($url, $queryParam, $body, $method);
  }


  /*
   * Execute the request
   *
   * @param url
   * @param data
   * @param body
   */
  private function execute($url, $queryParam, $body, $method) {

    $curl = curl_init();

    $headers = array();
    array_push($headers, 'X-BM-ApiKey: '.$this->sid);

    if (sizeof($queryParam) > 0) {
      $url .= '?'.http_build_query($queryParam);
    }

    curl_setopt_array($curl, GlobalEnv::$curlOptions + array(
      CURLOPT_URL => $url,
      CURLOPT_HTTPHEADER => $headers,
      CURLOPT_CUSTOMREQUEST => $method)
    );

    if ($method == 'POST') {
      curl_setopt($curl, CURLOPT_POST, TRUE);
      curl_setopt($curl, CURLOPT_POSTFIELDS, array());
    }

    if (is_resource($body)) {
      if ($method == 'PUT') {
        curl_setopt($curl, CURLOPT_PUT, TRUE);
      }
      $size = fstat($body)['size'];
      curl_setopt($curl, CURLOPT_INFILE, $body);
      curl_setopt($curl, CURLOPT_INFILESIZE, $size);
    } else {
      if (is_object($body) && method_exists($body, 'serialize')) {
        $body = $body->serialize();
      } else if (is_object($body)) {
        $body = json_encode($body);
      } else if (is_array($body)) {
        $body = json_encode($body);
      } else if (is_string($body)) {
        $body = json_encode($body);
      }
      $size = strlen($body);
      array_push($headers, 'Content-Type: application/json');
      array_push($headers, 'Content-Length: '.$size);
      curl_setopt($curl, CURLOPT_HTTPHEADER, $headers);
      curl_setopt($curl, CURLOPT_POSTFIELDS, $body);
    }

    $resp = curl_exec($curl);
    if ($resp === false) {
      throw new \Exception(curl_error($curl));
    } 
    curl_close($curl);
    if (!$resp) {
      return;
    }
    $js = json_decode($resp);
    if ($js === NULL) {
      return $resp;
    }
    if (isset($js->errorCode)) {
      throw new \Exception($js->errorCode . ': ' . (isset($js->message) ? ' : ' . $js->message : ''));
    }
    return $js;
  }

}
